import 'reflect-metadata'
import {Inject, Service} from "typedi"
import {PostModel} from "../models/post-model"
import {JWTUserPayload} from "../types"
import {getTimestampInSeconds, resultJson} from "../includes"

@Service()
export class PostService {
    @Inject()
    postModel!: PostModel

    async submit(jwtUserPayload: JWTUserPayload, content: string, image: string) {
        let packet = await this.postModel.insertPost({
            userId: jwtUserPayload.id,
            content: content,
            image: image,
            status: 1,
            time: getTimestampInSeconds()
        })
        return resultJson.success(packet.insertId)
    }

    async listPublished(page: number) {
        let posts = await this.postModel.findPostsByStatus(2, page)
        posts = posts.map((single: any) => {
            if (!single.nickname) {
                let stars = ''
                for (let i = 0; i < single.username.length - 6; i++) {
                    stars += '*'
                }
                single.nickname = single.username.substring(0, 4)
                    + stars
                    + single.username.substring(single.username.length - 2, single.username.length)
            }
            delete single.realName
            delete single.username
            return single
        })
        return resultJson.success(posts)
    }
}
